summaryrefslogtreecommitdiff
path: root/framework/Data/SqlMap/Configuration/TParameterMap.php
diff options
context:
space:
mode:
Diffstat (limited to 'framework/Data/SqlMap/Configuration/TParameterMap.php')
-rw-r--r--framework/Data/SqlMap/Configuration/TParameterMap.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/framework/Data/SqlMap/Configuration/TParameterMap.php b/framework/Data/SqlMap/Configuration/TParameterMap.php
index 8d09d9a9..e4d77a91 100644
--- a/framework/Data/SqlMap/Configuration/TParameterMap.php
+++ b/framework/Data/SqlMap/Configuration/TParameterMap.php
@@ -155,7 +155,7 @@ class TParameterMap extends TComponent
* @param mixed object to obtain the property from.
* @param TParameterProperty parameter property.
* @return mixed property value.
* @throws TSqlMapExecutionException if property access is invalid.
*/
protected function getObjectValue($object,$property)
{
@@ -165,7 +165,7 @@ class TParameterMap extends TComponent
}
catch (TInvalidPropertyException $e)
{
- throw new TSqlMapExecutionException(
+ throw new TSqlMapException(
'sqlmap_unable_to_get_property_for_parameter',
$this->getID(), $property->getProperty(), get_class($object));
}
@@ -155,7 +155,7 @@ class TParameterMap extends TComponent
* @param TParameterProperty parameter property.
* @return mixed property value.
- * @throws TSqlMapExecutionException if property access is invalid.
+ * @throws TSqlMapException if property access is invalid.
*/
protected function getObjectValue($object,$property)